@@ -29,7 +29,14 @@ from . import arg, types
 from .arg import Arg, Cmd, Expander, HelpCmd, Param, Positional
 from .collector import Instance
 from .errors import ArgErr, Err, ManyErr, Result, collect
-from .sources import CommandLine, EnvironmentVariables, IniSection, IniSectionSource, Source
+from .sources import (
+    CommandLine,
+    DefaultValue,
+    EnvironmentVariables,
+    IniSection,
+    IniSectionSource,
+    Source,
+)
 from .util import ClassDoc, filter_types_single
 
 C = TypeVar("C", bound="Config")
@@ -98,7 +105,8 @@ class ConfigProcessor(Generic[C]):
         ini_from_cl: Result[Sequence[Instance[Sequence[Path]]]] = cl[cs.ini_files]
         if isinstance(ini_from_cl, Err):
             return ini_from_cl
-        sources: List[Source] = [env]
+        default = DefaultValue()
+        sources: List[Source] = [default, env]
         ini_instances: Sequence[Path] = [
             ins for instances in [*ini_from_env, *ini_from_cl] for ins in instances.value
         ]
@@ -139,6 +147,9 @@ class ConfigStructure(Generic[C]):
     #: All parameters indexed by destination field
     params: Mapping[str, Param[Any]]
 
+    #: All commands
+    commands: Sequence[Cmd]
+
     #: Command-line commands that are not expanders
     cl_non_expander_cmds: Mapping[str, Cmd]
 
@@ -173,6 +184,7 @@ class ConfigStructure(Generic[C]):
 
         args: List[Arg] = []
         params: Dict[str, Param[Any]] = {}
+        commands: List[Cmd] = []
         cl_non_expander_cmds: Dict[str, Cmd] = {}
         cl_expanders: Dict[str, Expander] = {}
         cl_flag_params: Dict[str, Param[Any]] = {}
@@ -183,9 +195,6 @@ class ConfigStructure(Generic[C]):
 
         docs: ClassDoc[C] = ClassDoc.make(config_type)
 
-        def format_docstring(seq: Sequence[str]) -> str:
-            return textwrap.dedent("\n".join(seq))
-
         th = get_type_hints(config_type, include_extras=True)
         for name, typ in th.items():
             arg: Optional[Arg] = None
@@ -206,7 +215,7 @@ class ConfigStructure(Generic[C]):
                     help = "\n".join(help_lines)
                 arg = arg.updated(name, help, config_type.env_prefix_)
                 args.append(arg)
-                if name == "ini_files":
+                if name == "config":
                     assert isinstance(arg, Param)
                     ini_files = arg
 
@@ -224,6 +233,7 @@ class ConfigStructure(Generic[C]):
                 for name in arg.all_env_var_names():
                     env_params[name] = arg
             elif isinstance(arg, Cmd):
+                commands.append(arg)
                 for flag in arg.all_flags():
                     if isinstance(arg, Expander):
                         cl_expanders[flag] = arg
@@ -242,6 +252,7 @@ class ConfigStructure(Generic[C]):
             ini_files=ini_files,
             ini_sections=ini_sections,
             params=params,
+            commands=commands,
             cl_non_expander_cmds=cl_non_expander_cmds,
             cl_expanders=cl_expanders,
             cl_flag_params=cl_flag_params,
@@ -255,8 +266,10 @@ class ConfigStructure(Generic[C]):
             prog=self.prog,
             description=self.description,
             formatter_class=argparse.RawTextHelpFormatter,
+            add_help=False,
         )
         p._action_groups.pop()
+        commands = p.add_argument_group("commands")
         required = p.add_argument_group("required arguments")
         optional = p.add_argument_group("optional arguments")
         for param in self.params.values():
@@ -264,6 +277,10 @@ class ConfigStructure(Generic[C]):
                 required.add_argument(*param.all_flags(), **param.argparse_argument_kwargs())
             else:
                 optional.add_argument(*param.all_flags(), **param.argparse_argument_kwargs())
+        print(self.cl_expanders.values())
+        print(self.cl_non_expander_cmds.values())
+        for cmd in [*self.commands]:
+            commands.add_argument(*cmd.all_flags(), action="help")
         return p
 
 
@@ -277,7 +294,10 @@ class Config(abc.ABC):
     #:
     #: The paths are absolute or relative to the current working directory, and
     #: point to existing INI files containing configuration settings
-    ini_files: Annotated[Sequence[Path], Param.append(types.path.separated_by(","))]
+    config: Annotated[Sequence[Path], Param.append(types.path.separated_by(","))]
+
+    #: Display usage information and exits
+    help: ClassVar[HelpCmd] = HelpCmd(short_flag_name="-h", long_flag_name="--help")
 
     #: Names of sections to parse in configuration files, with unknown keys ignored
     ini_relaxed_sections_: ClassVar[Sequence[str]] = ["Common", "COMMON", "common"]
